Welcome to django-guardian documentation! — django-guardian v0.2.2 documentation

### Navigation

- index
- modules |
- next |
- django-guardian v0.2.2 documentation »

# Welcome to django-guardian documentation!

`django-guardian` is an implementation of object permissions for Django 1.2 providing extra authentication backend.

Features

- Object permissions for Django
- AnonymousUser support
- High level API
- Heavely tested

Incoming

- Django’s admin integration
- Management commands
- Decorators

# Documentation

Installation and project configuration

- Installation
- Configuration

Object permissions

- Assign object permissions
- Check object permissions
- Remove object permissions

Development

- Changelog
- Testing
- Example project

API

- API Reference
  - Backends
  - Core
  - Decorators
  - Models
  - Shortcuts
  - Template tags

# Source and issue tracker

Sources are available at issue-tracker. You may also file a bug there.

# Alternate projects

Django 1.2 still has only foundation for object permissions [1] and `django-guardian` make use of new facilities and it is based on them. There are some other pluggable applications which does NOT require latest 1.2 version of Django. For instance, there are great django-authority or django-permissions available out there.

# Other topics

- Index
- Search Page

[1] | See http://docs.djangoproject.com/en/1.2/topics/auth/#handling-object-permissions for more detail.

### Navigation

- index
- modules |
- next |
- django-guardian v0.2.2 documentation »